{% extends "base.html" %}

{% block title %}
Pathfinder Reports
{% endblock %}

{% block header %}
Pathfinder
{% endblock %}

{% block description %}
List Reports
{% endblock %}

{% block content %}
<div class="box box-primary">
    <div class="box-body">
        <table class="datatable table table-bordered table-hover">
            <thead>
                <tr>
                    <th>Report</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                {% for report in reports %}
                <tr>
                    <td>
                        {{report}}
                    </td>
                    <td>
                        <a href="{% url 'django-pathfinder-statcrunch-view-report' report.pk %}">View Report</a>
                    </td>
                </tr>
                {% endfor %}
                <!-- Bottom Divider -->

            </tbody>
        </table>
    </div>
</div>
{% endblock %}

{% block scripts %}
<script>
    $(function () {
        $('table').DataTable({
            'paging': false,
            'lengthChange': false,
            'searching': true,
            'ordering': true,
            'info': true,
            'autoWidth': false
        })
    })
</script>
{% endblock %}